@@ -21,8 +21,6 @@ if latex_available:
 else:
     plt.rc("text", usetex=False)
 
-# teal = (0, 100 / 255, 140 / 255)
-teal = "teal"
 colors = ["teal", "blue", "red", "blue", "purple", "orange"]
 # colors = np.random.permutation(colors)
 plt.rcParams["axes.prop_cycle"] = plt.cycler(color=colors)
@@ -114,8 +112,10 @@ def plot(
     xstep=1,
     ystep=1,
     ticks=True,
-    alpha=0.7,
+    alpha=0.8,
     grid=True,
+    lw=2.5,
+    domain=False,
 ):
     fig, ax = _get_figure_and_axis()
 
@@ -141,7 +141,10 @@ def plot(
     #         f"One of the provided functions is not defined on the provided domain: {domain}"
     #     )
 
-    x = np.linspace(xmin, xmax, int(2**12))
+    if domain:
+        x = np.linspace(domain[0], domain[1], int(2**12))
+    else:
+        x = np.linspace(xmin, xmax, int(2**12))
 
     if isinstance(fn_labels, bool) and fn_labels:  # If True, automatically set labels
         fn_labels = [f"${fn.__name__}$" for fn in functions]
@@ -151,13 +154,13 @@ def plot(
 
     if fn_labels is not None:
         for f, label in zip(functions, fn_labels):
-            ax.plot(x, f(x), lw=2, alpha=alpha, label=label)
+            ax.plot(x, f(x), lw=lw, alpha=alpha, label=label)
 
         ax.legend(fontsize=16)
 
     else:
         for f in functions:
-            ax.plot(x, f(x), lw=2, alpha=alpha)
+            ax.plot(x, f(x), lw=lw, alpha=alpha)
 
     plt.ylim(ymin, ymax)
     plt.xlim(xmin, xmax)
@@ -180,11 +183,12 @@ def multiplot(
     xstep=1,
     ystep=1,
     ticks=True,
-    alpha=0.7,
+    alpha=0.6,
     grid=True,
     rows=2,
     cols=2,
     figsize=(8, 6),
+    lw=2.5,
 ):
     figs, axes = _get_figures_and_axes(rows, cols, figsize)
 
@@ -213,7 +217,7 @@ def multiplot(
         fn_labels = [f"${label}$" for label in fn_labels]
 
     for f, ax, label in zip(functions, axes.flat, fn_labels):
-        ax.plot(x, f(x), lw=2, alpha=alpha, label=label)
+        ax.plot(x, f(x), lw=lw, alpha=alpha, label=label)
         ax.legend(fontsize=16)
 
     for ax in axes.flat:
@@ -269,6 +273,8 @@ def histogram(
     rotation=0,
     fontsize=16,
     norwegian=True,
+    lw=2.5,
+    alpha=0.6,
 ):
     heights = [f / b for f, b in zip(frequencies, binsizes)]
     fig, ax = _get_figure_and_axis()
@@ -321,10 +327,10 @@ def histogram(
 
     for i in range(len(x) - 1):
         ax.plot(
-            [x[i], x[i + 1]], [heights[i], heights[i]], color="teal", lw=2, alpha=0.7
+            [x[i], x[i + 1]], [heights[i], heights[i]], color="teal", lw=lw, alpha=alpha
         )
-        ax.plot([x[i], x[i]], [0, heights[i]], color="teal", lw=2, alpha=0.7)
-        ax.plot([x[i + 1], x[i + 1]], [0, heights[i]], color="teal", lw=2, alpha=0.7)
+        ax.plot([x[i], x[i]], [0, heights[i]], color="teal", lw=lw, alpha=alpha)
+        ax.plot([x[i + 1], x[i + 1]], [0, heights[i]], color="teal", lw=lw, alpha=alpha)
 
         ax.fill(
             [x[i], x[i + 1], x[i + 1], x[i]],
